#include <math.h>

#include "calc_energy.h"
/* DO NOT call the mcinl* innerloop routines directly unless
 * you know what you are doing - use the wrapper, and remember
 * to call the initialization routine first
 * so your LJ-parameter array is correctly setup :-)
 */


/* definition used in the energy routine */
void mcinl1100(int nri,int iinr[],int jindex[],int jjnr[],int shift[],
	       real shiftvec[],int gid[],real pos[],real charge[],real facel,
	       real Vc[],int type[],int ntype,real nbfp[],real Vnb[]);



real *setup_lj_parameters(real LJparam[], int ntype)
{
  int i,j;
  real *nbfp;

  nbfp=(real *)malloc(sizeof(real)*2*ntype*ntype);
  
  for(i=0;i<ntype;i++)
    for(j=0;j<ntype;j++) {
      nbfp[2*ntype*i+j]=sqrt(LJparam[2*i]*LJparam[2*j]);
      nbfp[2*ntype*i+j+1]=sqrt(LJparam[2*i+1]*LJparam[2*j+1]);
    }
  return nbfp;
}




void calc_energy(int nri,int iinr[],int jindex[],int jjnr[],int gid[],
		 real x[],real charge[],real VCoulomb[],
		 int LJtype[],int ntype,real LJparamarray[],real VLJ[])
{
  static int shiftidx=0;
  static real zeroshift[3]={0.0,0,0};
  static real facel=138.93541024; /* one/(4*pi*epsilon_0) */

  /* If you know that your machine and OS has e.g. SSE or 3DNow
   * support you can append _sse or _3dnow to the function name
   * -> mcinl1100_sse or mcinl1100_3dnow to get a considerably
   * faster routine.
   * If your macine doesn't support it you will get an illegal
   * instruction error. Just try it :-)
   *
   * For double precision you can append _sse2 if you have
   * a pentium 4 and linux kernel>=2.4, and your Gromacs library
   * was compiled in double precision!
   *
   * Dont forget to change the function definition above too! -
   * otherwise it wont work. And make sure all your arrays are
   * either float or double....
   */   
  mcinl1100(nri,iinr,jindex,jjnr,&shiftidx,zeroshift,gid,x,
	    charge,facel,VCoulomb,LJtype,ntype,LJparamarray,VLJ);
}
