

/* setup_lj_parameters takes a list of c6/c12 parameters
 * for atom types and creates a full interaction matrix
 * with geometrical combinations for nonbonded forces between
 * any atom pair.
 * 
 * Input:
 * LJparam - array with c6,c12 values of length 2*ntype.
 *           Example: c6[type0], c12[type0], c6[type1], c12[type1],...
 * ntype   - number of different atom types.
 *
 * Output:
 * The routine returns a pointer to an array of all geometrical
 * combinations of LJ paramters. The
 * interaction parameters between type i and type j is located
 * in:
 *    c6(i,j) = LJparamarray[2*ntype*i+2*j]
 *   c12(i,j) = LJparamarray[2*ntype*i+2*j+1]
 */
   
real *setup_lj_parameters(real LJparam[],int ntype);


/* This routine calculates Coulomb and LJ energies according
 * to the neighborlists you provide, and put the energies
 * into groups if you so wish. If you use a lot of groups
 * things will go slower :-)
 *
 *
 * Input:
 *
 * nri - number of i particles in the neighborlist
 * iinr - array with the i particle indices
 * jindex - array with limits for the j particles to use
 *          for each i particle.
 * jjnr  - array with j particle indices.
 * gid   - where the energy for this i particle should be put.
 *         (calculate it with the GID macro definition below)
 * x     - atom coordinate array.
 * charge - charge array
 * VCoulomb - Empty array of size gnr*gnr (gnr=number of grps)
 * LJtype - array with the LJ interaction type for each atom.
 * ntype  - number of different types.
 * LJparamarray - LJ parameters calculated with setup_lj_parameters.
 * VLJ    - Empty array of size gnr*gnr for LJ energies.
 *
 *
 * Output:
 * Energies are written to the VCoulomb and VLJ arrays.
 * If you have a total of gnr atom groups, the interactions
 * between atoms with group index i and j in this array
 * is in position GID(i,j,gnr). This is a gromacs macro
 * defined as
 *
 * ((igid < jgid) ? (igid*gnr+jgid) : (jgid*gnr+igid))
 * 
 */ 

void calc_energy();


